@@ -167,38 +167,26 @@ fn run_test(src: String, expected: String, syntax: Syntax, is_module: bool) {
         "optional" | "computed" | "static" | "abstract" | "declare" | "definite" | "generator"
         | "readonly" | "expression" => {
             // TODO(kdy1): Remove this
-            match v {
-                Value::Bool(false) => {
-                    *v = Value::Null;
-                }
-
-                _ => {}
+            if let Value::Bool(false) = v {
+                *v = Value::Null;
             }
         }
 
         "decorators" | "implements" => {
             // TODO(kdy1): Remove this
-            match v {
-                Value::Array(arr) => {
-                    if arr.is_empty() {
-                        *v = Value::Null;
-                    }
+            if let Value::Array(arr) = v {
+                if arr.is_empty() {
+                    *v = Value::Null;
                 }
-
-                _ => {}
             }
         }
 
         "sourceFile" => {
             // TODO(kdy1): Remove this
-            match v {
-                Value::String(s) => {
-                    if s.is_empty() {
-                        *v = Value::Null;
-                    }
+            if let Value::String(s) = v {
+                if s.is_empty() {
+                    *v = Value::Null;
                 }
-
-                _ => {}
             }
         }
 
